BasicIndicatorAttributes class

Inheritance

Constructors

BasicIndicatorAttributes({Color unselectedBackgroundColor = const Color(0x33FFFFFF), Color selectedBackgroundColor = Colors.white, Color unselectedBorderColor = Colors.transparent, Color selectedBorderColor = Colors.white, double borderSize = 1, double size = 8, Duration animationDuration = Durations.short4})

Properties

animationDuration Duration
final
borderSize double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBackgroundColor Color
final
selectedBorderColor Color
final
size double
final
unselectedBackgroundColor Color
final
unselectedBorderColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited