BasicIndicatorBuilder class

Inheritance

Constructors

BasicIndicatorBuilder({Key? key, required IndicatorStyle style, required bool isSelected, required BasicIndicatorAttributes attribute})
const

Properties

attribute BasicIndicatorAttributes
final
backgroundColor Color
no setter
circle Widget
no setter
circleDrop Widget
no setter
circleDuet Widget
no setter
hashCode int
The hash code for this object.
no setterinherited
horizontalPipe Widget
no setter
isSelected bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
line Widget
no setter
margin double
no setter
radius double
no setter
rectangle Widget
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
square Widget
no setter
squareDuet Widget
no setter
style IndicatorStyle
final
unselectedBackgroundColor Color
no setter
verticalPipe Widget
no setter

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited